==> jasper-doc-4.1.1-1-aarch64.pkg.tar.xz: usr/share/doc/JasPer/html/search/all_0.js <==
var searchData=
[
  ['a_20new_20image_20format_0',['Adding Support for a New Image Format',['../lib.html#lib__adding_codecs',1,'']]],
  ['adding_20support_20for_20a_20new_20image_20format_1',['Adding Support for a New Image Format',['../lib.html#lib__adding_codecs',1,'']]],
  ['additional_20examples_20of_20library_20setup_2',['Additional Examples of Library Setup',['../lib_init.html#init_setup_example_3',1,'']]],
  ['alloc_3',['alloc',['../structjas__allocator__s.html#aec0ad6f17c3f38750f8c1158698c5d4c',1,'jas_allocator_s']]],
  ['allocation_4',['allocation',['../group__module__alloc.html',1,'Memory Allocation'],['../lib.html#lib_alloc00',1,'Memory Allocation']]],
  ['allocator_20wrapper_5',['Memory Allocators and the Allocator Wrapper',['../lib_init.html#init_allocators',1,'']]],
  ['allocators_20and_20the_20allocator_20wrapper_6',['Memory Allocators and the Allocator Wrapper',['../lib_init.html#init_allocators',1,'']]],
  ['and_20color_20management_7',['Images, Sequences, and Color Management',['../lib_images.html',1,'lib']]],
  ['and_20matrices_8',['Sequences and Matrices',['../lib_images.html#images_seq',1,'']]],
  ['and_20reporting_9',['Bug Tracking and Reporting',['../bugs.html',1,'']]],
  ['and_20shutdown_10',['and shutdown',['../group__module__init.html',1,'Configuration, Initialization, and Shutdown'],['../lib_init.html#init_overview',1,'Configuration, Initialization, and Shutdown'],['../lib_init.html',1,'Configuration, Initialization, and Shutdown'],['../lib_init.html#init_setup_example_1',1,'Example of Code for Library Setup and Shutdown']]],
  ['and_20the_20allocator_20wrapper_11',['Memory Allocators and the Allocator Wrapper',['../lib_init.html#init_allocators',1,'']]],
  ['and_20two_20dimensional_20sequences_12',['One- and Two-Dimensional Sequences',['../group__module__seq.html',1,'']]],
  ['api_20references_13',['api references',['../lib_init.html#lib_init__api',1,'API References'],['../lib_images.html#lib_images__api',1,'API References'],['../lib_iostreams.html#lib_iostream__api',1,'API References'],['../lib_log.html#lib_log__api',1,'API References'],['../lib_math.html#lib_math__api',1,'API References'],['../lib_string.html#lib_string__api',1,'API References'],['../lib_timers.html#lib_timers__api',1,'API References']]],
  ['application_20programs_14',['JasPer Application Programs',['../apps.html',1,'']]],
  ['arithmetic_15',['Fixed-Point Arithmetic',['../group__module__fixed.html',1,'']]]
];

==> jasper-doc-4.2.5-1-aarch64.pkg.tar.xz: usr/share/doc/JasPer/html/search/all_0.js <==
var searchData=
[
  ['a_20new_20image_20format_0',['Adding Support for a New Image Format',['../lib.html#lib__adding_codecs',1,'']]],
  ['adding_20support_20for_20a_20new_20image_20format_1',['Adding Support for a New Image Format',['../lib.html#lib__adding_codecs',1,'']]],
  ['additional_20examples_20of_20library_20setup_2',['Additional Examples of Library Setup',['../lib_init.html#init_setup_example_3',1,'']]],
  ['alloc_3',['alloc',['../structjas__allocator__s.html#aec0ad6f17c3f38750f8c1158698c5d4c',1,'jas_allocator_s']]],
  ['allocation_4',['Allocation',['../group__module__alloc.html',1,'Memory Allocation'],['../lib.html#lib_alloc00',1,'Memory Allocation']]],
  ['allocator_20wrapper_5',['Memory Allocators and the Allocator Wrapper',['../lib_init.html#init_allocators',1,'']]],
  ['allocators_20and_20the_20allocator_20wrapper_6',['Memory Allocators and the Allocator Wrapper',['../lib_init.html#init_allocators',1,'']]],
  ['and_20color_20management_7',['Images, Sequences, and Color Management',['../lib_images.html',1,'lib']]],
  ['and_20matrices_8',['Sequences and Matrices',['../lib_images.html#images_seq',1,'']]],
  ['and_20reporting_9',['Bug Tracking and Reporting',['../bugs.html',1,'']]],
  ['and_20shutdown_10',['and Shutdown',['../group__module__init.html',1,'Configuration, Initialization, and Shutdown'],['../lib_init.html',1,'Configuration, Initialization, and Shutdown'],['../lib_init.html#init_overview',1,'Configuration, Initialization, and Shutdown'],['../lib_init.html#init_setup_example_1',1,'Example of Code for Library Setup and Shutdown']]],
  ['and_20the_20allocator_20wrapper_11',['Memory Allocators and the Allocator Wrapper',['../lib_init.html#init_allocators',1,'']]],
  ['and_20two_20dimensional_20sequences_12',['One- and Two-Dimensional Sequences',['../group__module__seq.html',1,'']]],
  ['api_20references_13',['API References',['../lib_init.html#lib_init__api',1,'API References'],['../lib_images.html#lib_images__api',1,'API References'],['../lib_iostreams.html#lib_iostream__api',1,'API References'],['../lib_log.html#lib_log__api',1,'API References'],['../lib_math.html#lib_math__api',1,'API References'],['../lib_string.html#lib_string__api',1,'API References'],['../lib_timers.html#lib_timers__api',1,'API References']]],
  ['application_20programs_14',['JasPer Application Programs',['../apps.html',1,'']]],
  ['arithmetic_15',['Fixed-Point Arithmetic',['../group__module__fixed.html',1,'']]]
];
